![Tests](https://github.com/Harrison88/redtrio/workflows/Tests/badge.svg)
[![codecov](https://codecov.io/gh/Harrison88/redtrio/branch/master/graph/badge.svg)](https://codecov.io/gh/Harrison88/redtrio)
[![PyPI](https://img.shields.io/pypi/v/redtrio.svg)](https://pypi.org/project/redtrio/)
